ref_url: https://twitter.com/justmarkham/status/1168930165658914816 ref_name: Kevin Markham's Twitter ---

> 🐼🤹‍♂️ pandas trick:
> ⚠️ Got bad data (or empty rows) at the top of your CSV file? Use these read_csv parameters:
> ➡️ header = row number of header (start counting at 0)
> ➡️ skiprows = list of row numbers to skip
> See example 👇#Python #DataScience #pandas #pandastricks pic.twitter.com/t1M6XkkPYG

> — Kevin Markham (@justmarkham) September 3, 2019